import{O as r}from"./router.57d0b938.js";import{d as l,Z as i,o as c,et as u,b as a,w as n,u as o,ar as d,cR as f,cQ as b}from"./vue-router.9c189215.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="cd20555e-5b37-4452-bc65-54158bdfd5fe",e._sentryDebugIdIdentifier="sentry-dbid-cd20555e-5b37-4452-bc65-54158bdfd5fe")}catch{}})();const p=l({__name:"OidcLoginCallback",setup(e){return i(async()=>{await new r().loginCallback()}),(t,s)=>(c(),u("div",null,[a(o(f),null,{default:n(()=>[d("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLoginCallback.7197aa71.js.map
