import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.bc9f966a.js";import{d as s,eA as i,o as a,c as f,u as m}from"./vue-router.9c189215.js";import"./gateway.9f52e1b9.js";import"./popupNotifcation.36212eac.js";import"./fetch.cbad757f.js";import"./record.81eab1e4.js";import"./SaveButton.d65552d2.js";import"./ExclamationCircleOutlined.e7e177bc.js";import"./CrudView.232cb2b0.js";import"./router.e3c5e041.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.c0e8bace.js";import"./BookOutlined.09421b52.js";import"./url.31fc40ca.js";import"./index.25372697.js";import"./index.cef5be1e.js";import"./PhRocketLaunch.vue.d1ef7089.js";import"./asyncComputed.9b764511.js";import"./PhPencil.vue.bead5e13.js";import"./index.aa9903a2.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="3ac09bf7-5f7c-4f77-8fe1-379e01241b4f",o._sentryDebugIdIdentifier="sentry-dbid-3ac09bf7-5f7c-4f77-8fe1-379e01241b4f")}catch{}})();const A=s({__name:"EnvVars",setup(o){const r=i().params.projectId,t=new p(r);return(c,d)=>(a(),f(n,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.d2a0b9b3.js.map
