import{O as d}from"./router.57d0b938.js";import{d as l,Z as u,o as i,et as c,b as a,w as o,u as n,ar as s,cR as f,cQ as b}from"./vue-router.9c189215.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="44e0be43-d7a8-423b-ac36-b529094bd8f7",e._sentryDebugIdIdentifier="sentry-dbid-44e0be43-d7a8-423b-ac36-b529094bd8f7")}catch{}})();const p=l({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new d().logoutCallback()}),(t,r)=>(i(),c("div",null,[a(n(f),null,{default:o(()=>[s("You're authenticated")]),_:1}),a(n(b),null,{default:o(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLogoutCallback.b7f3bed3.js.map
