import{eZ as t,e_ as r}from"./vue-router.9c189215.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="d3a92728-c26e-479c-823c-54d32ac8630b",e._sentryDebugIdIdentifier="sentry-dbid-d3a92728-c26e-479c-823c-54d32ac8630b")}catch{}})();function o(e,n){return t(1,arguments),r(e,Date.now(),n)}export{o as f};
//# sourceMappingURL=index.bf0eb142.js.map
