import{C as g}from"./CrudView.232cb2b0.js";import{a as d}from"./ant-design.ffef9ea6.js";import{a as b}from"./asyncComputed.9b764511.js";import{d as w,eA as _,eM as h,f as I,o as k,c as v,u as x,eN as C}from"./vue-router.9c189215.js";import{a as M}from"./gateway.9f52e1b9.js";import"./tables.7c712ae1.js";import{M as n}from"./member.daac5b6f.js";import"./router.e3c5e041.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.c0e8bace.js";import"./BookOutlined.09421b52.js";import"./url.31fc40ca.js";import"./index.25372697.js";import"./index.cef5be1e.js";import"./popupNotifcation.36212eac.js";import"./record.81eab1e4.js";import"./string.ab5242d0.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[a]="b7f07dd9-5be5-4d88-9a43-7989761c24fc",o._sentryDebugIdIdentifier="sentry-dbid-b7f07dd9-5be5-4d88-9a43-7989761c24fc")}catch{}})();const K=w({__name:"Editors",setup(o){const a=_(),s=h(),r=a.params.organizationId,l=[{key:"email",label:"Email"}],m=async e=>{await n.create(r,e.email),c()};async function u(e){var t;if(((t=M.getAuthor())==null?void 0:t.claims.email)===e.email&&await d("You are about to remove your own access. You won't be able to access this organization anymore. Are you sure?")){await n.delete(r,e.authorId),await s.push({name:"organizations"});return}await d("Are you sure you want to remove this member's access?")&&(await n.delete(r,e.authorId),c())}const{loading:f,result:p,refetch:c}=b(()=>n.list(r)),y=I(()=>{var e,i;return{columns:[{name:"Email",align:"left"},{name:"Role"},{name:"",align:"right"}],rows:(i=(e=p.value)==null?void 0:e.map(t=>({key:t.email,cells:[{type:"text",text:t.email},{type:"text",text:t.role},{type:"actions",actions:[{icon:C,label:"Remove access",onClick:()=>u(t),dangerous:!0}]}]})))!=null?i:[]}});return(e,i)=>(k(),v(g,{"entity-name":"editors",loading:x(f),title:"Organization editors",description:"List all organization editors.","empty-title":"No editors yet",table:y.value,"create-button-text":"Add editors",fields:l,onCreate:m},null,8,["loading","table"]))}});export{K as default};
//# sourceMappingURL=Editors.121b85b9.js.map
