import{a6 as s,dh as i}from"./vue-router.9c189215.js";import{g as d}from"./index.be605f3e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="adcc3582-a6a0-4c19-8397-8c83ecbf3ca0",e._sentryDebugIdIdentifier="sentry-dbid-adcc3582-a6a0-4c19-8397-8c83ecbf3ca0")}catch{}})();const{DatePicker:n,WeekPicker:c,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:t,RangePicker:a}=d(i),y=s(n,{WeekPicker:c,MonthPicker:r,YearPicker:f,RangePicker:a,TimePicker:m,QuarterPicker:t,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(r.name,r),e.component(c.name,c),e.component(t.name,t),e)});export{y as D,r as M,t as Q,a as R,c as W};
//# sourceMappingURL=dayjs.d970bc65.js.map
