import{d as t,o,et as s,b as d,u as r,bj as _,R as c}from"./vue-router.9c189215.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="30754679-279a-4e04-9ffa-553c35bcaab8",e._sentryDebugIdIdentifier="sentry-dbid-30754679-279a-4e04-9ffa-553c35bcaab8")}catch{}})();const i={class:"centered"},f=t({__name:"LoadingContainer",setup(e){return(n,a)=>(o(),s("div",i,[d(r(_))]))}});const u=c(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.91064174.js.map
