import{u as k}from"./router.57d0b938.js";import{d as _,L as w,N as d,e as g,o as r,et as v,b as s,w as h,u as e,c as p,ev as m,R as T}from"./vue-router.9c189215.js";import{K,_ as R,W as I,P,b as S}from"./WorkflowView.ea80b333.js";import{P as V}from"./api.39bb761e.js";import{A as c,T as x}from"./TabPane.1c00cd5f.js";import"./Card.2a8e9df0.js";import"./fetch.cbad757f.js";import"./linters.28fa212f.js";import"./asyncComputed.9b764511.js";import"./scripts.a3fa69df.js";import"./record.81eab1e4.js";import"./metadata.8d3d9e54.js";import"./PhCheckCircle.vue.77d168c1.js";import"./PhKanban.vue.79a750bc.js";import"./PhWebhooksLogo.vue.4027a276.js";import"./ant-design.ffef9ea6.js";import"./index.cef5be1e.js";import"./index.25372697.js";import"./index.bf0eb142.js";import"./index.11ff09de.js";import"./CollapsePanel.3444ba0b.js";import"./index.cfeca020.js";import"./index.270bafb6.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.e28d4fad.js";import"./model.8e9c7094.js";import"./workspaces.071bd719.js";import"./runnerData.bc555239.js";import"./url.31fc40ca.js";import"./validations.3502c42f.js";import"./string.ab5242d0.js";import"./PhArrowSquareOut.vue.ddd88f8c.js";import"./index.52637728.js";import"./Badge.8f0bc30f.js";import"./index.aa9903a2.js";import"./uuid.29ec31f9.js";import"./LoadingOutlined.2e22119b.js";import"./DeleteOutlined.45422492.js";import"./PhDownloadSimple.vue.f8d96320.js";import"./utils.cbbe8440.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="afe9ac84-82ed-4159-99e6-02d6ffcbcdc4",t._sentryDebugIdIdentifier="sentry-dbid-afe9ac84-82ed-4159-99e6-02d6ffcbcdc4")}catch{}})();const W={class:"threads-view"},A=_({__name:"Threads",setup(t){const a=k().authHeaders,b=new V(a),i=new P(a),u=new S(a),f=new w(d.array(d.string()),"kanban-selected-stages"),o=g("kanban");return(B,l)=>(r(),v("div",W,[s(e(x),{activeKey:o.value,"onUpdate:activeKey":l[0]||(l[0]=y=>o.value=y)},{default:h(()=>[s(e(c),{key:"kanban",tab:"Kanban View"}),s(e(c),{key:"table",tab:"Table View"}),s(e(c),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),o.value==="kanban"?(r(),p(K,{key:0,"kanban-repository":e(i),"kanban-stages-storage":e(f),"stage-run-repository":e(u)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):m("",!0),o.value==="table"?(r(),p(R,{key:1,"kanban-repository":e(i)},null,8,["kanban-repository"])):m("",!0),o.value==="workflow"?(r(),p(I,{key:2,"kanban-repository":e(i),"workflow-api":e(b)},null,8,["kanban-repository","workflow-api"])):m("",!0)]))}});const ge=T(A,[["__scopeId","data-v-86c0b860"]]);export{ge as default};
//# sourceMappingURL=Threads.85068342.js.map
