import{g as _}from"./api.d4de5847.js";import{W as g}from"./Watermark.aed0590d.js";import{i as h}from"./metadata.8d3d9e54.js";import{a as k}from"./asyncComputed.9b764511.js";import{W as b}from"./WidgetsFrame.196bc760.js";import{F as w}from"./PhArrowSquareOut.vue.ddd88f8c.js";import{d as v,eM as x,f as C,u as e,o as s,c as m,w as a,ev as D,b as n,cN as p,ar as f,et as F,eC as I,cV as u,eD as V,ez as W,aD as z,R as N}from"./vue-router.9c189215.js";import"./index.153d639d.js";import{C as T}from"./Card.2a8e9df0.js";import"./router.57d0b938.js";import"./runnerData.bc555239.js";import"./url.31fc40ca.js";import"./PhCheckCircle.vue.77d168c1.js";import"./PhKanban.vue.79a750bc.js";import"./PhWebhooksLogo.vue.4027a276.js";import"./TabPane.1c00cd5f.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="f6e2d349-39d8-4280-94fc-178e210d9ac7",o._sentryDebugIdIdentifier="sentry-dbid-f6e2d349-39d8-4280-94fc-178e210d9ac7")}catch{}})();const B=v({__name:"Home",setup(o){const i=x(),{result:t}=k(_),d=C(()=>{var r;return((r=t.value)==null?void 0:r.sidebar.filter(l=>l.id!=="home"))||[]}),y=r=>{i.push({path:`/${r}`})};return(r,l)=>e(t)?(s(),m(b,{key:0,class:"home-container","main-color":e(t).mainColor,theme:e(t).theme,"font-family":e(t).fontFamily},{default:a(()=>[n(e(u),{vertical:"",gap:"large",class:"cards-container"},{default:a(()=>[d.value.length===0?(s(),m(e(p),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:a(()=>[f(" There are no forms available for you. ")]),_:1})):(s(!0),F(z,{key:1},I(d.value,c=>(s(),m(e(T),{key:c.id,class:"form-card",onClick:H=>y(c.path)},{default:a(()=>[n(e(u),{gap:"large",align:"center",justify:"space-between"},{default:a(()=>[(s(),m(V(e(h)(c.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),n(e(p),{style:{"font-size":"18px","font-weight":"500"}},{default:a(()=>[f(W(c.name),1)]),_:2},1024),n(e(w),{size:"20"})]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1}),n(g,{class:"watermark","page-id":"home"})]),_:1},8,["main-color","theme","font-family"])):D("",!0)}});const X=N(B,[["__scopeId","data-v-3be5f215"]]);export{X as default};
//# sourceMappingURL=Home.06aac4d8.js.map
