import{L as v}from"./Logo.d24d6b8e.js";import{a as k}from"./asyncComputed.9b764511.js";import{d as A,eA as x,eM as C,f as I,o as i,et as N,b as n,w as t,u as e,c as _,ev as f,f2 as s,ar as a,ez as l,cR as B,cN as m,bG as D,a as T,cO as E,R}from"./vue-router.9c189215.js";import{g as V}from"./api.d4de5847.js";import{C as L}from"./Card.2a8e9df0.js";import"./router.57d0b938.js";import"./runnerData.bc555239.js";import"./url.31fc40ca.js";import"./TabPane.1c00cd5f.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new z().stack;c&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[c]="24d048b1-9a2b-443f-924d-8b2729ae911a",o._sentryDebugIdIdentifier="sentry-dbid-24d048b1-9a2b-443f-924d-8b2729ae911a")}catch{}})();const G={class:"inner-content"},H={class:"card-content"},j=A({__name:"Error",setup(o){var b,y,h;const c=x(),p=C(),{result:u}=k(V),g=(h=(b=u.value)==null?void 0:b.name)!=null?h:(y=u.value)==null?void 0:y.brandName,r=I(()=>{const{status:d}=c.params;switch(d){case"404":return{status:d,title:s.translate("i18n_page_not_found"),message:s.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:d,title:s.translate("i18n_access_denied"),message:s.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:s.translate("i18n_internal_error"),message:s.translate("i18n_internal_error_message"),showAd:!1}}}),w=()=>{p.push({name:"playerHome"})};return(d,M)=>(i(),N("div",G,[n(e(B),null,{default:t(()=>[a(l(r.value.title),1)]),_:1}),n(e(m),{class:"message"},{default:t(()=>[a(l(r.value.message),1)]),_:1}),r.value.action?(i(),_(e(D),{key:0,type:"link",onClick:w},{default:t(()=>[a(l(r.value.action),1)]),_:1})):f("",!0),r.value.showAd?(i(),_(e(L),{key:1,bordered:!1,class:"card"},{default:t(()=>[T("div",H,[n(v,{style:{"margin-bottom":"10px"}}),n(e(m),null,{default:t(()=>[a("This page is part of "+l(e(g)?`the ${e(g)}`:"a")+" workflow, built with Abstra.",1)]),_:1}),e(u)?(i(),_(e(m),{key:0},{default:t(()=>[a("Automate your own processes by getting started "),n(e(E),{href:"https://abstra.io"},{default:t(()=>[a("here")]),_:1}),a(".")]),_:1})):f("",!0)])]),_:1})):f("",!0)]))}});const z=R(j,[["__scopeId","data-v-599c1508"]]);export{z as default};
//# sourceMappingURL=Error.c81fee31.js.map
