import{P as m}from"./PlayerNavbar.992f3f03.js";import{u as _,b as f}from"./router.57d0b938.js";import{d as h,eM as g,eA as s,f as y,r as v,o as b,et as w,b as r,u as i,a as L,R as I}from"./vue-router.9c189215.js";import"./metadata.8d3d9e54.js";import"./PhCheckCircle.vue.77d168c1.js";import"./PhKanban.vue.79a750bc.js";import"./PhWebhooksLogo.vue.4027a276.js";import"./asyncComputed.9b764511.js";import"./PhSignOut.vue.657fb9d5.js";import"./api.d4de5847.js";import"./runnerData.bc555239.js";import"./url.31fc40ca.js";import"./index.4a96abf3.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="4df4c03d-a9af-4d05-8f78-215553662349",t._sentryDebugIdIdentifier="sentry-dbid-4df4c03d-a9af-4d05-8f78-215553662349")}catch{}})();const k={class:"main-container"},N={class:"content"},R=h({__name:"Main",setup(t){const e=g(),o=_(),c=s().path,u=({path:n})=>{e.push({path:`/${n}`})},d=()=>{e.push({name:"playerLogin"})},p=y(()=>!!s().meta.hideLogin);return f(()=>e.push({name:"playerLogin"})),(n,x)=>{var a;const l=v("RouterView");return b(),w("div",k,[r(m,{"current-path":i(c),"user-email":(a=i(o).user)==null?void 0:a.claims.email,onNavigate:u,onLoginClick:d,"hide-login":p.value},null,8,["current-path","user-email","hide-login"]),L("section",N,[r(l)])])}}});const q=I(R,[["__scopeId","data-v-c786764c"]]);export{q as default};
//# sourceMappingURL=Main.c4135b6d.js.map
