import{d as n,o as s,et as a,a as d,dA as r,ex as c,R as l}from"./vue-router.9c189215.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4f3613e6-fcc7-4b42-bec4-37001a2999e0",e._sentryDebugIdIdentifier="sentry-dbid-4f3613e6-fcc7-4b42-bec4-37001a2999e0")}catch{}})();const _={class:"content-layout"},u=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(s(),a("div",_,[d("div",{class:c(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const i=l(u,[["__scopeId","data-v-6397d501"]]);export{i as C};
//# sourceMappingURL=ContentLayout.31c0f5cd.js.map
