import{d as i,o as n,c as p,w as a,b as s,u as e}from"./vue-router.9c189215.js";import"./linters.28fa212f.js";import{W as m}from"./workspaces.071bd719.js";import{C as d}from"./ContentLayout.31c0f5cd.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.bc9f966a.js";import"./asyncComputed.9b764511.js";import"./runnerData.bc555239.js";import"./url.31fc40ca.js";import"./record.81eab1e4.js";import"./gateway.9f52e1b9.js";import"./popupNotifcation.36212eac.js";import"./fetch.cbad757f.js";import"./SaveButton.d65552d2.js";import"./ExclamationCircleOutlined.e7e177bc.js";import"./CrudView.232cb2b0.js";import"./router.e3c5e041.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.c0e8bace.js";import"./BookOutlined.09421b52.js";import"./index.25372697.js";import"./index.cef5be1e.js";import"./PhRocketLaunch.vue.d1ef7089.js";import"./PhPencil.vue.bead5e13.js";import"./index.aa9903a2.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="a056a25e-0b61-4b00-a936-80d2ce022066",o._sentryDebugIdIdentifier="sentry-dbid-a056a25e-0b61-4b00-a936-80d2ce022066")}catch{}})();const q=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(t,u)=>(n(),p(d,null,{default:a(()=>[s(f,{"env-var-repository":e(r),mode:"editor","file-opender":e(m)},null,8,["env-var-repository","file-opender"])]),_:1}))}});export{q as default};
//# sourceMappingURL=EnvVarsEditor.ba03ff92.js.map
