import{R as n,o as d,et as o,dA as s,a,ev as r}from"./vue-router.9c189215.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="a38eb98d-b08c-4626-8ca8-8d4ad10d1867",e._sentryDebugIdIdentifier="sentry-dbid-a38eb98d-b08c-4626-8ca8-8d4ad10d1867")}catch{}})();const c={},i={class:"base-layout"},u={class:"base-middle"},_={key:0,class:"base-footer"};function f(e,t){return d(),o("div",i,[s(e.$slots,"sidebar",{},void 0,!0),a("section",u,[s(e.$slots,"navbar",{},void 0,!0),s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(d(),o("section",_,[s(e.$slots,"footer",{},void 0,!0)])):r("",!0)])])}const y=n(c,[["render",f],["__scopeId","data-v-9ad5be20"]]);export{y as B};
//# sourceMappingURL=BaseLayout.98e2cf68.js.map
