import{d as f,eA as b,eM as C,f as g,o as _,c as h,u as w,eN as I}from"./vue-router.9c189215.js";import{b as k}from"./tables.7c712ae1.js";import"./gateway.9f52e1b9.js";import{C as i}from"./connector.f03e800e.js";import{a as x}from"./asyncComputed.9b764511.js";import{G as E}from"./PhPencil.vue.bead5e13.js";import{C as D}from"./CrudView.232cb2b0.js";import"./record.81eab1e4.js";import"./string.ab5242d0.js";import"./popupNotifcation.36212eac.js";import"./router.e3c5e041.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.c0e8bace.js";import"./BookOutlined.09421b52.js";import"./url.31fc40ca.js";import"./index.25372697.js";import"./index.cef5be1e.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="efe3ebe6-9189-4521-9ad8-e54c4571a2db",o._sentryDebugIdIdentifier="sentry-dbid-efe3ebe6-9189-4521-9ad8-e54c4571a2db")}catch{}})();const H=f({__name:"Connectors",setup(o){const r=b(),a=C(),c=r.params.projectId;async function s(e){const t=await i.create(c,e.name,e.type);a.push({name:"connectorEditor",params:{connectorId:t.id}})}const p=[{key:"name",label:"Connector name",type:"text"},{key:"type",label:"Connector type",type:Object.entries(k.schema).map(([e,t])=>({value:e,label:t.label}))}],{loading:l,result:m,refetch:d}=x(()=>i.list(c)),u=g(()=>{var e,t;return{columns:[{name:"Name"},{name:"Type"},{name:"",align:"right"}],rows:(t=(e=m.value)==null?void 0:e.map(n=>({key:n.id,cells:[{type:"link",text:n.name,to:{name:"connectorEditor",params:{connectorId:n.id}}},{type:"text",text:n.type},{type:"actions",actions:[{icon:E,label:"Edit",onClick({key:y}){a.push({name:"connectorEditor",params:{connectorId:y}})}},{icon:I,label:"Delete",dangerous:!0,async onClick(){await n.delete(),d()}}]}]})))!=null?t:[]}});return(e,t)=>(_(),h(D,{"entity-name":"connector",loading:w(l),title:"Connectors",description:"Each connector is a version of your app. You can create a new connector by deploying your app from the local editor.","empty-title":"No connectors here yet",table:u.value,fields:p,"create-button-text":"Create connector",onCreate:s},null,8,["loading","table"]))}});export{H as default};
//# sourceMappingURL=Connectors.b8f74089.js.map
