import{d,o as s,et as t,ev as n,eH as c,eI as _,a as r,R as p}from"./vue-router.9c189215.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="f27dda11-3d0c-43e2-b0ba-de58949bb9e1",e._sentryDebugIdIdentifier="sentry-dbid-f27dda11-3d0c-43e2-b0ba-de58949bb9e1")}catch{}})();const b="/assets/logo.0faadfa2.svg",i=e=>(c("data-v-a421cbdb"),e=e(),_(),e),l={class:"logo"},f=i(()=>r("img",{class:"logo-img",src:b,alt:"Abstra Logo"},null,-1)),g={key:0},u=d({__name:"Logo",props:{hideText:{type:Boolean}},setup(e){return(o,a)=>(s(),t("div",l,[f,o.hideText?n("",!0):(s(),t("span",g,"Abstra"))]))}});const m=p(u,[["__scopeId","data-v-a421cbdb"]]);export{m as L};
//# sourceMappingURL=Logo.d24d6b8e.js.map
