import{a as g}from"./asyncComputed.9b764511.js";import{d as y,eA as _,Z as w,u as e,o as l,c as b,et as x,b as a,w as o,cR as C,ar as p,cV as h,bG as I,a as k,ez as v}from"./vue-router.9c189215.js";import"./gateway.9f52e1b9.js";import"./tables.7c712ae1.js";import{O as z}from"./organization.0c38ee68.js";import{C as c}from"./router.e3c5e041.js";import{L as B}from"./LoadingContainer.91064174.js";import{A as D}from"./index.cfeca020.js";import{C as N}from"./Card.2a8e9df0.js";import"./popupNotifcation.36212eac.js";import"./record.81eab1e4.js";import"./string.ab5242d0.js";import"./TabPane.1c00cd5f.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="a1a3f468-a1e6-4291-ada4-4904b915ac44",t._sentryDebugIdIdentifier="sentry-dbid-a1a3f468-a1e6-4291-ada4-4904b915ac44")}catch{}})();const A={key:1},M={style:{display:"flex","justify-content":"flex-start","font-size":"24px"}},J=y({__name:"Billing",setup(t){const s=_().params.organizationId,{loading:u,result:f}=g(()=>z.get(s));w(()=>{location.search.includes("upgrade")&&c.showNewMessage("I want to upgrade my plan")});const m=()=>c.showNewMessage("I want to upgrade my plan");return(V,j)=>e(u)?(l(),b(B,{key:0})):(l(),x("div",A,[a(e(h),{justify:"space-between",align:"center"},{default:o(()=>[a(e(C),{level:3},{default:o(()=>[p("Current plan")]),_:1})]),_:1}),a(e(D),{style:{"margin-top":"0"}}),a(e(N),{style:{width:"300px"},title:"Plan"},{extra:o(()=>[a(e(I),{onClick:m},{default:o(()=>[p("Upgrade")]),_:1})]),default:o(()=>{var r,i,d;return[k("div",M,v((d=(i=(r=e(f))==null?void 0:r.billingMetadata)==null?void 0:i.plan)!=null?d:"No active plan"),1)]}),_:1})]))}});export{J as default};
//# sourceMappingURL=Billing.cc2cf8a0.js.map
