import{C as t,E as d,K as i,a as c,M as f,c as l,P as y,R as g,S as u,b,T as k,U as p,e as w,l as D}from"./toggleHighContrast.09b748d0.js";import"./vue-router.9c189215.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="fc6c068d-c550-4467-94e9-90778dc372c6",e._sentryDebugIdIdentifier="sentry-dbid-fc6c068d-c550-4467-94e9-90778dc372c6")}catch{}})();export{t as CancellationTokenSource,d as Emitter,i as KeyCode,c as KeyMod,f as MarkerSeverity,l as MarkerTag,y as Position,g as Range,u as Selection,b as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.534a2a35.js.map
