import{B as d}from"./BookOutlined.09421b52.js";import{d as c,o as a,c as f,w as o,b as l,u as n,dA as u,et as i,ar as p,aD as b,bG as y}from"./vue-router.9c189215.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="3ae473cb-2b43-4867-8150-ec677c43f384",t._sentryDebugIdIdentifier="sentry-dbid-3ae473cb-2b43-4867-8150-ec677c43f384")}catch{}})();const g=c({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var s;return a(),f(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank",type:"text",size:"small"},{icon:o(()=>[l(n(d))]),default:o(()=>[e.$slots.default?u(e.$slots,"default",{key:0}):(a(),i(b,{key:1},[p("Docs")],64))]),_:3},8,["href"])}}});export{g as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.c0e8bace.js.map
